from distutils.core import setup

setup(
	name		= 'islist',
	version		= '1.1.0',
	py_modules	= ['islist'],
	author		= 'taehwan.koo',
	author_email	= 'simple_guy87@naver.com',
	description	= 'A simple printer of nested lists',
     )
